Inline stream processors for image augmentation:

* `add-annotation-overlay-od`: adds object detection overlays to images
* `crop`: crops images
* `flip`: flips images either left-to-right, up-to-down or both
* `gaussian-blur`: applies gaussian blur to images
* `hsl-grayscale`: turns RGB images into fake grayscale ones by converting them to HSL and then using the L channel for all three channels
* `linear-contrast`: applies linear contrast to images
* `rotate`: rotates images by a specified degree (0-360) or randomly within degree range
* `scale`: scales images by a specified percentage (0-1) or randomly within percentage range
